package WordList::MetaSyntactic::dangdut;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2020-05-01'; # DATE
our $DIST = 'WordList-MetaSyntactic-dangdut'; # DIST
our $VERSION = '0.003'; # VERSION

use parent qw(WordListBase::MetaSyntactic);

1;
# ABSTRACT: Wordlist from Acme::MetaSyntactic::dangdut

__END__

=pod

=encoding UTF-8

=head1 NAME

WordList::MetaSyntactic::dangdut - Wordlist from Acme::MetaSyntactic::dangdut

=head1 VERSION

This document describes version 0.003 of WordList::MetaSyntactic::dangdut (from Perl distribution WordList-MetaSyntactic-dangdut), released on 2020-05-01.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/WordList-MetaSyntactic-dangdut>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-WordList-MetaSyntactic-dangdut>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=WordList-MetaSyntactic-dangdut>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<WordList>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
